@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2024, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2026, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -210,6 +210,7 @@ public class LocaleNames_bs extends OpenListResourceBundle {
             { "IL", "Izrael" },
             { "IM", "Ostrvo Man" },
             { "IN", "Indija" },
+            { "IO", "Britanska Teritorija u Indijskom Okeanu" },
             { "IQ", "Irak" },
             { "IR", "Iran" },
             { "IS", "Island" },
@@ -582,6 +583,7 @@ public class LocaleNames_bs extends OpenListResourceBundle {
             { "bin", "bini" },
             { "bkm", "kom" },
             { "bla", "siksika" },
+            { "blo", "anii" },
             { "bra", "braj" },
             { "brx", "bodo" },
             { "bss", "akoski" },
@@ -719,6 +721,7 @@ public class LocaleNames_bs extends OpenListResourceBundle {
             { "kum", "kumik" },
             { "kut", "kutenai" },
             { "kwk", "kvakvala" },
+            { "kxv", "kuvi" },
             { "lad", "ladino" },
             { "lag", "langi" },
             { "lah", "landa" },
@@ -736,7 +739,6 @@ public class LocaleNames_bs extends OpenListResourceBundle {
             { "lua", "luba-lulua" },
             { "lui", "luiseno" },
             { "lun", "lunda" },
-            { "luo", "luo" },
             { "lus", "mizo" },
             { "luy", "luhija" },
             { "mad", "madure\u0161ki" },
@@ -854,6 +856,7 @@ public class LocaleNames_bs extends OpenListResourceBundle {
             { "swb", "komorski" },
             { "syc", "klasi\u010dni sirijski" },
             { "syr", "sirijski" },
+            { "szl", "\u0161leski" },
             { "tce", "ju\u017eni tu\u010doni" },
             { "tem", "timne" },
             { "teo", "teso" },
@@ -882,8 +885,8 @@ public class LocaleNames_bs extends OpenListResourceBundle {
             { "uga", "ugaritski" },
             { "umb", "umbundu" },
             { "und", "nepoznati jezik" },
-            { "vai", "vai" },
             { "vec", "venecijanski" },
+            { "vmw", "makua" },
             { "vot", "votski" },
             { "vun", "vunjo" },
             { "wae", "valser" },
@@ -893,6 +896,7 @@ public class LocaleNames_bs extends OpenListResourceBundle {
             { "wbp", "varlpiri" },
             { "wuu", "Wu kineski" },
             { "xal", "kalmik" },
+            { "xnr", "kangri" },
             { "xog", "soga" },
             { "yao", "jao" },
             { "yap", "jape\u0161ki" },
@@ -1311,7 +1315,7 @@ public class LocaleNames_bs extends OpenListResourceBundle {
             { "type.co.emoji", "Sortiranje po emoji sli\u010dicama" },
             { "type.lb.loose", "Slobodni stil prijeloma reda" },
             { "type.nu.roman", "rimski brojevi" },
-            { "type.ca.coptic", "Koptski kalendar" },
+            { "type.ca.coptic", "koptski kalendar" },
             { "type.ca.hebrew", "hebrejski kalendar" },
             { "type.ca.indian", "indijski nacionalni kalendar" },
             { "type.co.compat", "Prethodno sortiranje radi uskla\u0111enosti" },
@@ -1326,7 +1330,7 @@ public class LocaleNames_bs extends OpenListResourceBundle {
             { "type.lb.strict", "Strogi stil prijeloma reda" },
             { "type.m0.ungegn", "UN GEGN transliteracija" },
             { "type.ms.metric", "metri\u010dki sistem" },
-            { "type.nu.native", "Izvorne cifre" },
+            { "type.nu.native", "izvorni brojevi" },
             { "type.ca.chinese", "kineski kalendar" },
             { "type.ca.islamic", "islamski kalendar" },
             { "type.ca.iso8601", "kalendar ISO-8601" },
@@ -1368,6 +1372,8 @@ public class LocaleNames_bs extends OpenListResourceBundle {
             { "type.co.dictionary", "Rje\u010dni\u010dko sortiranje" },
             { "type.co.traditional", "Tradicionalno sortiranje" },
             { "type.nu.traditional", "Tradicionalni brojevi" },
+            { "type.ca.islamic-rgsa", "islamski kalendar za Saudijsku Arabiju" },
+            { "type.ca.islamic-tbla", "islamski kalendar, tabelarni, astronomska epoha" },
             { "type.ca.islamic-civil", "islamski gra\u0111anski kalendar, tabelarni" },
             { "type.ca.islamic-umalqura", "islamski kalendar, Umm al-Qura" },
             { "type.ca.ethiopic-amete-alem", "etiopski kalendar \"Amete Alem\"" },
